==> blesta-5.10.2.zip: blesta/components/modules/solusvm/language/cs_cz/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_client_ips.cancel'] = 'Zrušit';
$lang['Solusvm.tab_client_ips.remove_ip'] = 'Odstranění IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = 'Opravdu chcete tuto IP adresu trvale odstranit?';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = 'Odebrat IP adresu %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = 'Primární IP adresa';
$lang['Solusvm.tab_client_ips.heading_extra'] = 'Další IP adresy';
$lang['Solusvm.tab_ips.confirm_remove'] = 'Opravdu chcete tuto IP adresu trvale odstranit?';
$lang['Solusvm.tab_ips.option_remove'] = 'Odstranění IP';
$lang['Solusvm.tab_ips.heading_options'] = 'Možnosti';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP adresa';
$lang['Solusvm.tab_ips.heading_extra_ips'] = 'Další IP adresy';
$lang['Solusvm.tab_ips.primary_ip'] = 'Primární IP adresa: %1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP adresy';
$lang['Solusvm.tab_client_console.vnc_password'] = 'Heslo VNC';
$lang['Solusvm.tab_client_console.console_password'] = 'Heslo konzoly';
$lang['Solusvm.tab_client_console.console_username'] = 'Uživatelské jméno konzole';
$lang['Solusvm.tab_client_console.heading_console'] = 'Konzole';
$lang['Solusvm.tab_console.vnc_password'] = 'Heslo VNC:';
$lang['Solusvm.tab_console.vnc_port'] = 'Port VNC:';
$lang['Solusvm.tab_console.vnc_ip'] = 'Hostitel VNC:';
$lang['Solusvm.tab_console.console_password'] = 'Heslo konzole:';
$lang['Solusvm.tab_console.console_username'] = 'Uživatelské jméno konzole:';
$lang['Solusvm.tab_console.heading_console'] = 'Konzole';
$lang['Solusvm.tab_client_stats.heading_graphs'] = 'Grafy';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = 'Místo na disku';
$lang['Solusvm.tab_client_stats.memory'] = 'Paměť';
$lang['Solusvm.tab_client_stats.bandwidth'] = 'Šířka pásma';
$lang['Solusvm.tab_client_stats.heading_stats'] = 'Statistiky';
$lang['Solusvm.tab_stats.heading_graphs'] = 'Grafy';
$lang['Solusvm.tab_status.no_results'] = 'Statistiky nejsou v současné době k dispozici.';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = 'Místo na disku:';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = 'Paměť:';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = 'Šířka pásma:';
$lang['Solusvm.tab_stats.heading_stats'] = 'Statistiky';
$lang['Solusvm.tab_client_actions.text_generate_password'] = 'Generování hesla';
$lang['Solusvm.tab_client_actions.field_password_submit'] = 'Změna hesla';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = 'Potvrzení hesla';
$lang['Solusvm.tab_client_actions.field_password'] = 'Nové kořenové heslo';
$lang['Solusvm.tab_client_actions.heading_password'] = 'Změna hesla';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_client_actions.field_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = 'Změna názvu hostitele se projeví až po restartu serveru.';
$lang['Solusvm.tab_client_actions.heading_hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_client_actions.field_confirm'] = 'Chápu, že přeinstalováním budou všechna data na serveru trvale odstraněna a bude nainstalována vybraná šablona.';
$lang['Solusvm.tab_client_actions.field_template'] = 'Šablona';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_client_actions.status_disabled'] = 'Bezbariérový';
$lang['Solusvm.tab_client_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_client_actions.status_online'] = 'Online';
$lang['Solusvm.tab_client_actions.heading_node'] = 'Uzel';
$lang['Solusvm.tab_client_actions.heading_server_status'] = 'Stav serveru';
$lang['Solusvm.tab_client_actions.heading_actions'] = 'Akce';
$lang['Solusvm.tab_actions.text_generate_password'] = 'Generování hesla';
$lang['Solusvm.tab_actions.field_password_submit'] = 'Změna hesla';
$lang['Solusvm.tab_actions.field_confirm_password'] = 'Potvrzení hesla';
$lang['Solusvm.tab_actions.field_password'] = 'Nové kořenové heslo';
$lang['Solusvm.tab_actions.heading_password'] = 'Změna hesla';
$lang['Solusvm.tab_actions.field_hostname_submit'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_actions.field_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = 'Změna názvu hostitele se projeví až po restartu serveru.';
$lang['Solusvm.tab_actions.heading_hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_actions.field_confirm'] = 'Chápu, že přeinstalováním budou všechna data na serveru trvale odstraněna a bude nainstalována vybraná šablona.';
$lang['Solusvm.tab_actions.field_template'] = 'Šablona';
$lang['Solusvm.tab_actions.heading_reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_actions.node'] = 'Uzel: %1$s';
$lang['Solusvm.tab_actions.server_status'] = 'Stav serveru';
$lang['Solusvm.tab_actions.status_disabled'] = 'Bezbariérový';
$lang['Solusvm.tab_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_actions.status_online'] = 'Online';
$lang['Solusvm.tab_actions.heading_actions'] = 'Akce';
$lang['Solusvm.tab_ips'] = 'IP adresy';
$lang['Solusvm.tab_console'] = 'Konzole';
$lang['Solusvm.tab_stats'] = 'Statistiky';
$lang['Solusvm.tab_actions'] = 'Akce serveru';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = 'Primární IP adresa';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = 'ID virtuálního serveru určuje VPS ze SolusVM, ke kterému bude tato služba připojena. Změna této hodnoty ovlivní tuto službu pouze lokálně.';
$lang['Solusvm.service_field.solusvm_vserver_id'] = 'ID virtuálního serveru';
$lang['Solusvm.service_field.solusvm_template'] = 'Šablona';
$lang['Solusvm.service_field.solusvm_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.package_fields.node_group'] = 'Skupina uzlů';
$lang['Solusvm.package_fields.set_node_group'] = 'Přiřazení skupiny uzlů';
$lang['Solusvm.package_fields.set_node'] = 'Přiřazení sady uzlů';
$lang['Solusvm.package_fields.available_nodes'] = 'Dostupné uzly';
$lang['Solusvm.package_fields.assigned_nodes'] = 'Přiřazené uzly';
$lang['Solusvm.package_fields.plan'] = 'Plán';
$lang['Solusvm.package_fields.client_set_template'] = 'Nechte klienta nastavit šablonu';
$lang['Solusvm.package_fields.admin_set_template'] = 'Výběr šablony';
$lang['Solusvm.package_fields.template'] = 'Šablona';
$lang['Solusvm.package_fields.type'] = 'Typ';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = 'Zadejte celkový počet IP adres, které chcete zahrnout do nových služeb. Musí jich být alespoň jedna a IP adresy nelze odstranit.';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = 'Základní IP adresa Množství';
$lang['Solusvm.edit_row.add_btn'] = 'Aktualizační server';
$lang['Solusvm.edit_row.basic_title'] = 'Základní nastavení';
$lang['Solusvm.edit_row.box_title'] = 'Upravit server SolusVM';
$lang['Solusvm.add_row.add_btn'] = 'Přidat server';
$lang['Solusvm.add_row.basic_title'] = 'Základní nastavení';
$lang['Solusvm.add_row.box_title'] = 'Přidání serveru SolusVM';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = 'Xen';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'Číslo portu SSL';
$lang['Solusvm.row_meta.host'] = 'Hostitelské jméno';
$lang['Solusvm.row_meta.key'] = 'Klíč';
$lang['Solusvm.row_meta.user_id'] = 'ID uživatele';
$lang['Solusvm.row_meta.server_name'] = 'Označení serveru';
$lang['Solusvm.order_options.first'] = 'První neplnohodnotný server';
$lang['Solusvm.manage.module_groups_no_results'] = 'Neexistují žádné skupiny serverů.';
$lang['Solusvm.manage.module_rows_no_results'] = 'Neexistují žádné servery.';
$lang['Solusvm.manage.module_groups.confirm_delete'] = 'Opravdu chcete tuto skupinu serverů odstranit?';
$lang['Solusvm.manage.module_rows.confirm_delete'] = 'Opravdu chcete tento server odstranit?';
$lang['Solusvm.manage.module_groups.delete'] = 'Odstranit';
$lang['Solusvm.manage.module_rows.delete'] = 'Odstranit';
$lang['Solusvm.manage.module_groups.edit'] = 'Upravit';
$lang['Solusvm.manage.module_rows.edit'] = 'Upravit';
$lang['Solusvm.manage.module_groups_heading.options'] = 'Možnosti';
$lang['Solusvm.manage.module_groups_heading.servers'] = 'Počet serverů';
$lang['Solusvm.manage.module_groups_heading.name'] = 'Název skupiny';
$lang['Solusvm.manage.module_rows_heading.options'] = 'Možnosti';
$lang['Solusvm.manage.module_rows_heading.host'] = 'Hostitelské jméno';
$lang['Solusvm.manage.module_rows_heading.server_label'] = 'Označení serveru';
$lang['Solusvm.manage.module_groups_title'] = 'Skupiny hlavních serverů SolusVM';
$lang['Solusvm.manage.module_rows_title'] = 'Hlavní servery SolusVM';
$lang['Solusvm.add_module_group'] = 'Přidání skupiny serverů';
$lang['Solusvm.add_module_row'] = 'Přidat server';
$lang['Solusvm.module_group'] = 'Hlavní skupina SolusVM';
$lang['Solusvm.module_row_plural'] = 'Servery';
$lang['Solusvm.module_row'] = 'Hlavní server SolusVM';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) je výkonný systém pro správu VPS založený na grafickém rozhraní s plnou podporou OpenVZ, Linux KVM, Xen Paravirtualization a Xen HVM.';
$lang['Solusvm.name'] = 'SolusVM';
$lang['Solusvm.!percent.used'] = '%1$s%';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- Vyberte prosím --';
$lang['Solusvm.!success.reinstall'] = 'Server se nyní přeinstalovává.';
$lang['Solusvm.!success.hostname'] = 'Název hostitele byl úspěšně změněn.';
$lang['Solusvm.!success.password'] = 'Heslo bylo úspěšně změněno.';
$lang['Solusvm.!success.shutdown'] = 'Server se nyní vypíná.';
$lang['Solusvm.!success.reboot'] = 'Server se nyní restartuje.';
$lang['Solusvm.!success.boot'] = 'Server se nyní spouští.';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = 'Počet dalších IP adres nelze snížit, aniž by bylo určeno, které IP adresy mají být odstraněny.';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = 'ID virtuálního serveru musí být celé číslo.';
$lang['Solusvm.!error.solusvm_root_password.matches'] = 'Kořenová hesla se neshodují.';
$lang['Solusvm.!error.solusvm_root_password.length'] = 'Heslo kořene musí mít alespoň 6 znaků.';
$lang['Solusvm.!error.api.confirm.valid'] = 'Abyste mohli provést přeinstalaci šablony, musíte potvrdit, že rozumíte akci přeinstalace.';
$lang['Solusvm.!error.api.template.valid'] = 'Vybraná šablona je neplatná.';
$lang['Solusvm.!error.create_client.failed'] = 'Došlo k interní chybě a klientský účet nebylo možné vytvořit.';
$lang['Solusvm.!error.solusvm_template.valid'] = 'Vyberte platnou šablonu.';
$lang['Solusvm.!error.solusvm_hostname.format'] = 'Pro název hostitele zadejte platný plně kvalifikovaný název domény (např. host.domain.com).';
$lang['Solusvm.!error.api.internal'] = 'Došlo k interní chybě nebo server na požadavek neodpověděl.';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = 'Pro množství IP adres zadejte pouze číslice s hodnotou 1 nebo více.';
$lang['Solusvm.!error.meta[template].empty'] = 'Vyberte šablonu.';
$lang['Solusvm.!error.meta[set_template].format'] = 'Nastavte, zda chcete vybrat šablonu, nebo zda chcete umožnit klientům nastavit šablonu.';
$lang['Solusvm.!error.meta[plan].empty'] = 'Vyberte plán.';
$lang['Solusvm.!error.meta[nodes].empty'] = 'Vyberte alespoň jeden uzel nebo skupinu uzlů.';
$lang['Solusvm.!error.meta[type].valid'] = 'Vyberte platný typ virtualizace.';
$lang['Solusvm.!error.port.format'] = 'Zadejte platné číslo portu.';
$lang['Solusvm.!error.host.format'] = 'Název hostitele se zdá být neplatný.';
$lang['Solusvm.!error.key.empty'] = 'Zadejte prosím klíč.';
$lang['Solusvm.!error.user_id.empty'] = 'Zadejte prosím ID uživatele.';
$lang['Solusvm.!error.server_name.empty'] = 'Zadejte prosím označení serveru.';
$lang['SolusVM.!error.simplexml_required'] = 'Pro tento modul je vyžadováno rozšíření simplexml.';
$lang['Solusvm.!actions.password'] = 'Změna hesla';
$lang['Solusvm.!actions.hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.!actions.reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.!actions.shutdown'] = 'Vypnutí';
$lang['Solusvm.!actions.reboot'] = 'Restart';
$lang['Solusvm.!actions.boot'] = 'Boty';

==> blesta-5.11.4.zip: blesta/components/modules/solusvm/language/cs_cz/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_client_ips.cancel'] = 'Zrušit';
$lang['Solusvm.tab_client_ips.remove_ip'] = 'Odstranění IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = 'Opravdu chcete tuto IP adresu trvale odstranit?';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = 'Odebrat IP adresu %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = 'Primární IP adresa';
$lang['Solusvm.tab_client_ips.heading_extra'] = 'Další IP adresy';
$lang['Solusvm.tab_ips.confirm_remove'] = 'Opravdu chcete tuto IP adresu trvale odstranit?';
$lang['Solusvm.tab_ips.option_remove'] = 'Odstranění IP';
$lang['Solusvm.tab_ips.heading_options'] = 'Možnosti';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP adresa';
$lang['Solusvm.tab_ips.heading_extra_ips'] = 'Další IP adresy';
$lang['Solusvm.tab_ips.primary_ip'] = 'Primární IP adresa: %1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP adresy';
$lang['Solusvm.tab_client_console.vnc_password'] = 'Heslo VNC';
$lang['Solusvm.tab_client_console.console_password'] = 'Heslo konzoly';
$lang['Solusvm.tab_client_console.console_username'] = 'Uživatelské jméno konzole';
$lang['Solusvm.tab_client_console.heading_console'] = 'Konzole';
$lang['Solusvm.tab_console.vnc_password'] = 'Heslo VNC:';
$lang['Solusvm.tab_console.vnc_port'] = 'Port VNC:';
$lang['Solusvm.tab_console.vnc_ip'] = 'Hostitel VNC:';
$lang['Solusvm.tab_console.console_password'] = 'Heslo konzole:';
$lang['Solusvm.tab_console.console_username'] = 'Uživatelské jméno konzole:';
$lang['Solusvm.tab_console.heading_console'] = 'Konzole';
$lang['Solusvm.tab_client_stats.heading_graphs'] = 'Grafy';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = 'Místo na disku';
$lang['Solusvm.tab_client_stats.memory'] = 'Paměť';
$lang['Solusvm.tab_client_stats.bandwidth'] = 'Šířka pásma';
$lang['Solusvm.tab_client_stats.heading_stats'] = 'Statistiky';
$lang['Solusvm.tab_stats.heading_graphs'] = 'Grafy';
$lang['Solusvm.tab_status.no_results'] = 'Statistiky nejsou v současné době k dispozici.';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = 'Místo na disku:';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = 'Paměť:';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = 'Šířka pásma:';
$lang['Solusvm.tab_stats.heading_stats'] = 'Statistiky';
$lang['Solusvm.tab_client_actions.text_generate_password'] = 'Generování hesla';
$lang['Solusvm.tab_client_actions.field_password_submit'] = 'Změna hesla';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = 'Potvrzení hesla';
$lang['Solusvm.tab_client_actions.field_password'] = 'Nové kořenové heslo';
$lang['Solusvm.tab_client_actions.heading_password'] = 'Změna hesla';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_client_actions.field_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = 'Změna názvu hostitele se projeví až po restartu serveru.';
$lang['Solusvm.tab_client_actions.heading_hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_client_actions.field_confirm'] = 'Chápu, že přeinstalováním budou všechna data na serveru trvale odstraněna a bude nainstalována vybraná šablona.';
$lang['Solusvm.tab_client_actions.field_template'] = 'Šablona';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_client_actions.status_disabled'] = 'Bezbariérový';
$lang['Solusvm.tab_client_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_client_actions.status_online'] = 'Online';
$lang['Solusvm.tab_client_actions.heading_node'] = 'Uzel';
$lang['Solusvm.tab_client_actions.heading_server_status'] = 'Stav serveru';
$lang['Solusvm.tab_client_actions.heading_actions'] = 'Akce';
$lang['Solusvm.tab_actions.text_generate_password'] = 'Generování hesla';
$lang['Solusvm.tab_actions.field_password_submit'] = 'Změna hesla';
$lang['Solusvm.tab_actions.field_confirm_password'] = 'Potvrzení hesla';
$lang['Solusvm.tab_actions.field_password'] = 'Nové kořenové heslo';
$lang['Solusvm.tab_actions.heading_password'] = 'Změna hesla';
$lang['Solusvm.tab_actions.field_hostname_submit'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_actions.field_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = 'Změna názvu hostitele se projeví až po restartu serveru.';
$lang['Solusvm.tab_actions.heading_hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_actions.field_confirm'] = 'Chápu, že přeinstalováním budou všechna data na serveru trvale odstraněna a bude nainstalována vybraná šablona.';
$lang['Solusvm.tab_actions.field_template'] = 'Šablona';
$lang['Solusvm.tab_actions.heading_reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.tab_actions.node'] = 'Uzel: %1$s';
$lang['Solusvm.tab_actions.server_status'] = 'Stav serveru';
$lang['Solusvm.tab_actions.status_disabled'] = 'Bezbariérový';
$lang['Solusvm.tab_actions.status_offline'] = 'Offline';
$lang['Solusvm.tab_actions.status_online'] = 'Online';
$lang['Solusvm.tab_actions.heading_actions'] = 'Akce';
$lang['Solusvm.tab_ips'] = 'IP adresy';
$lang['Solusvm.tab_console'] = 'Konzole';
$lang['Solusvm.tab_stats'] = 'Statistiky';
$lang['Solusvm.tab_actions'] = 'Akce serveru';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = 'Primární IP adresa';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = 'ID virtuálního serveru určuje VPS ze SolusVM, ke kterému bude tato služba připojena. Změna této hodnoty ovlivní tuto službu pouze lokálně.';
$lang['Solusvm.service_field.solusvm_vserver_id'] = 'ID virtuálního serveru';
$lang['Solusvm.service_field.solusvm_template'] = 'Šablona';
$lang['Solusvm.service_field.solusvm_hostname'] = 'Hostitelské jméno';
$lang['Solusvm.package_fields.node_group'] = 'Skupina uzlů';
$lang['Solusvm.package_fields.set_node_group'] = 'Přiřazení skupiny uzlů';
$lang['Solusvm.package_fields.set_node'] = 'Přiřazení sady uzlů';
$lang['Solusvm.package_fields.available_nodes'] = 'Dostupné uzly';
$lang['Solusvm.package_fields.assigned_nodes'] = 'Přiřazené uzly';
$lang['Solusvm.package_fields.plan'] = 'Plán';
$lang['Solusvm.package_fields.client_set_template'] = 'Nechte klienta nastavit šablonu';
$lang['Solusvm.package_fields.admin_set_template'] = 'Výběr šablony';
$lang['Solusvm.package_fields.template'] = 'Šablona';
$lang['Solusvm.package_fields.type'] = 'Typ';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = 'Zadejte celkový počet IP adres, které chcete zahrnout do nových služeb. Musí jich být alespoň jedna a IP adresy nelze odstranit.';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = 'Základní IP adresa Množství';
$lang['Solusvm.edit_row.add_btn'] = 'Aktualizační server';
$lang['Solusvm.edit_row.basic_title'] = 'Základní nastavení';
$lang['Solusvm.edit_row.box_title'] = 'Upravit server SolusVM';
$lang['Solusvm.add_row.add_btn'] = 'Přidat server';
$lang['Solusvm.add_row.basic_title'] = 'Základní nastavení';
$lang['Solusvm.add_row.box_title'] = 'Přidání serveru SolusVM';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = 'Xen';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'Číslo portu SSL';
$lang['Solusvm.row_meta.host'] = 'Hostitelské jméno';
$lang['Solusvm.row_meta.key'] = 'Klíč';
$lang['Solusvm.row_meta.user_id'] = 'ID uživatele';
$lang['Solusvm.row_meta.server_name'] = 'Označení serveru';
$lang['Solusvm.order_options.first'] = 'První neplnohodnotný server';
$lang['Solusvm.manage.module_groups_no_results'] = 'Neexistují žádné skupiny serverů.';
$lang['Solusvm.manage.module_rows_no_results'] = 'Neexistují žádné servery.';
$lang['Solusvm.manage.module_groups.confirm_delete'] = 'Opravdu chcete tuto skupinu serverů odstranit?';
$lang['Solusvm.manage.module_rows.confirm_delete'] = 'Opravdu chcete tento server odstranit?';
$lang['Solusvm.manage.module_groups.delete'] = 'Odstranit';
$lang['Solusvm.manage.module_rows.delete'] = 'Odstranit';
$lang['Solusvm.manage.module_groups.edit'] = 'Upravit';
$lang['Solusvm.manage.module_rows.edit'] = 'Upravit';
$lang['Solusvm.manage.module_groups_heading.options'] = 'Možnosti';
$lang['Solusvm.manage.module_groups_heading.servers'] = 'Počet serverů';
$lang['Solusvm.manage.module_groups_heading.name'] = 'Název skupiny';
$lang['Solusvm.manage.module_rows_heading.options'] = 'Možnosti';
$lang['Solusvm.manage.module_rows_heading.host'] = 'Hostitelské jméno';
$lang['Solusvm.manage.module_rows_heading.server_label'] = 'Označení serveru';
$lang['Solusvm.manage.module_groups_title'] = 'Skupiny hlavních serverů SolusVM';
$lang['Solusvm.manage.module_rows_title'] = 'Hlavní servery SolusVM';
$lang['Solusvm.add_module_group'] = 'Přidání skupiny serverů';
$lang['Solusvm.add_module_row'] = 'Přidat server';
$lang['Solusvm.module_group'] = 'Hlavní skupina SolusVM';
$lang['Solusvm.module_row_plural'] = 'Servery';
$lang['Solusvm.module_row'] = 'Hlavní server SolusVM';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) je výkonný systém pro správu VPS založený na grafickém rozhraní s plnou podporou OpenVZ, Linux KVM, Xen Paravirtualization a Xen HVM.';
$lang['Solusvm.name'] = 'SolusVM';
$lang['Solusvm.!percent.used'] = '%1$s';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- Vyberte prosím --';
$lang['Solusvm.!success.reinstall'] = 'Server se nyní přeinstalovává.';
$lang['Solusvm.!success.hostname'] = 'Název hostitele byl úspěšně změněn.';
$lang['Solusvm.!success.password'] = 'Heslo bylo úspěšně změněno.';
$lang['Solusvm.!success.shutdown'] = 'Server se nyní vypíná.';
$lang['Solusvm.!success.reboot'] = 'Server se nyní restartuje.';
$lang['Solusvm.!success.boot'] = 'Server se nyní spouští.';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = 'Počet dalších IP adres nelze snížit, aniž by bylo určeno, které IP adresy mají být odstraněny.';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = 'ID virtuálního serveru musí být celé číslo.';
$lang['Solusvm.!error.solusvm_root_password.matches'] = 'Kořenová hesla se neshodují.';
$lang['Solusvm.!error.solusvm_root_password.length'] = 'Heslo kořene musí mít alespoň 6 znaků.';
$lang['Solusvm.!error.api.confirm.valid'] = 'Abyste mohli provést přeinstalaci šablony, musíte potvrdit, že rozumíte akci přeinstalace.';
$lang['Solusvm.!error.api.template.valid'] = 'Vybraná šablona je neplatná.';
$lang['Solusvm.!error.create_client.failed'] = 'Došlo k interní chybě a klientský účet nebylo možné vytvořit.';
$lang['Solusvm.!error.solusvm_template.valid'] = 'Vyberte platnou šablonu.';
$lang['Solusvm.!error.solusvm_hostname.format'] = 'Pro název hostitele zadejte platný plně kvalifikovaný název domény (např. host.domain.com).';
$lang['Solusvm.!error.api.internal'] = 'Došlo k interní chybě nebo server na požadavek neodpověděl.';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = 'Pro množství IP adres zadejte pouze číslice s hodnotou 1 nebo více.';
$lang['Solusvm.!error.meta[template].empty'] = 'Vyberte šablonu.';
$lang['Solusvm.!error.meta[set_template].format'] = 'Nastavte, zda chcete vybrat šablonu, nebo zda chcete umožnit klientům nastavit šablonu.';
$lang['Solusvm.!error.meta[plan].empty'] = 'Vyberte plán.';
$lang['Solusvm.!error.meta[nodes].empty'] = 'Vyberte alespoň jeden uzel nebo skupinu uzlů.';
$lang['Solusvm.!error.meta[type].valid'] = 'Vyberte platný typ virtualizace.';
$lang['Solusvm.!error.port.format'] = 'Zadejte platné číslo portu.';
$lang['Solusvm.!error.host.format'] = 'Název hostitele se zdá být neplatný.';
$lang['Solusvm.!error.key.empty'] = 'Zadejte prosím klíč.';
$lang['Solusvm.!error.user_id.empty'] = 'Zadejte prosím ID uživatele.';
$lang['Solusvm.!error.server_name.empty'] = 'Zadejte prosím označení serveru.';
$lang['SolusVM.!error.simplexml_required'] = 'Pro tento modul je vyžadováno rozšíření simplexml.';
$lang['Solusvm.!actions.password'] = 'Změna hesla';
$lang['Solusvm.!actions.hostname'] = 'Změna názvu hostitele';
$lang['Solusvm.!actions.reinstall'] = 'Přeinstalujte stránky';
$lang['Solusvm.!actions.shutdown'] = 'Vypnutí';
$lang['Solusvm.!actions.reboot'] = 'Restart';
$lang['Solusvm.!actions.boot'] = 'Boty';
